(*******************************************************************************
*                                                                              *
*                             Delphi BasicAssist                               *
*                                                                              *
*                     (C)Copyright 2001, Ferns Paanakker.                      *
*                                                                              *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU General Public License as published by      *
*    the Free Software Foundation; either version 2 of the License, or         *
*    (at your option) any later version.                                       *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU General Public License for more details.                              *
*                                                                              *
*    You should have received a copy of the GNU General Public License         *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************)

unit BasicAssist;

interface

uses BasicType, sysutils;

(* String helper functions *)
function GetBracketPart(cMsg: string; var nStart: integer): string;
function GetLastPart(cMsg: string): string;

function GetToken(cMsg: string; pos: integer): string;
function GetTokenPos(cMsg: string; pos: integer): integer;
function GetInteger(cMsg: string; pos: integer): integer;
function GetDouble(cMsg: string; pos: integer): double;
function RemoveAllBrackets(c: string): string;
function RemoveSpace(c: string): string;

(* StrToType functions *)
function StrToPlayMode(cMode: string): TPlayMode;
function StrToSide(c: string): TSide;
function StrToPosition(c: string): TPosition;
function StrToKind(c: string): TKind;

(* TypeToStr functions *)
function PlayModeToStr(pm: TPlayMode): string;
function SideToStr(side: TSide): string;

(* Angle helper functions *)
function RelToAbs(FaceDir, RelAngle: double): double;
function AbsToRel(AbsAngle, FaceDir: double): double;
function SinAngle(angle: double): double;
function CosAngle(angle: double): double;

implementation

function GetBracketPart(cMsg: string; var nStart: integer): string;
var
  nCount: integer;
  len: integer;
begin
  nCount := 0;
  len := length(cMsg);
  result := '';
  while (nStart <= len) do
  begin
    if cMsg[nStart] = '(' then
      Inc(nCount);

    if nCount > 0 then
      result := result + cMsg[nStart];

    if cMsg[nStart] = ')' then
    begin
      Dec(nCount);
      if nCount = 0 then
        exit;
    end;
    Inc(nStart);
  end;
end;

function GetLastPart(cMsg: string): string;
var
  nPos: integer;
begin
  Result := '';
  nPos := Length(cMsg);
  // Skip over ')'
  while ((nPos > 1) and (cMsg[nPos] = ')')) do
    Dec(nPos);
  while ((nPos > 1) and (cMsg[nPos] <> ')')) do
  begin
    Result := cMsg[nPos] + Result;
    Dec(nPos);
  end;
  Result := trim(Result);
end;

(*
  Simple helper function to return string at a position.
  example:
    'This is    really simple',0   -> This
    'This is    really simple',1   -> is
    'This is    really simple',2   -> really
    'This is    really simple',3   -> simple
*)
function GetToken(cMsg: string; pos: integer): string;
var
  i: integer;
  len: integer;
  nSwitch: integer;
begin
  result := '';
  nSwitch := 0;
  i := 1;
  len := length(cMsg);

  while ((i <= len) and (nSwitch < pos)) do
  begin
    while ((i <= len) and (cMsg[i] <> ' ')) do
      Inc(i);
    while ((i <= len) and (cMsg[i] = ' ')) do
      Inc(i);
    Inc(nSwitch);
  end;

  while ((i <= len) and (cMsg[i] <> ' ')) do
  begin
    Result := Result + cMsg[i];
    Inc(i);
  end;
end;

function GetTokenPos(cMsg: string; pos: integer): integer;
var
  i: integer;
  len: integer;
  nSwitch: integer;
begin
  nSwitch := 0;
  i := 1;
  len := length(cMsg);

  while ((i <= len) and (nSwitch < pos)) do
  begin
    while ((i <= len) and (cMsg[i] <> ' ')) do
      Inc(i);
    while ((i <= len) and (cMsg[i] = ' ')) do
      Inc(i);
    Inc(nSwitch);
  end;

  if i = len then
    result := 0
  else
    result := i;
end;


function GetInteger(cMsg: string; pos: integer): integer;
begin
  result := StrToInt(GetToken(cMsg, Pos));
end;

function GetDouble(cMsg: string; pos: integer): double;
begin
  DecimalSeparator := '.';
  result := StrToFloat(GetToken(cMsg, Pos));
end;

function StrToPlayMode(cMode: string): TPlayMode;
begin
  if (CompareText(cMode, 'before_kick_off') = 0) then
    result := pm_before_kick_off
  else if (CompareText(cMode, 'kick_off_l') = 0) then
    result := pm_kick_off_l
  else if (CompareText(cMode, 'kick_off_r') = 0) then
    result := pm_kick_off_r
  else if (CompareText(cMode, 'kick_in_l') = 0) then
    result := pm_kick_in_l
  else if (CompareText(cMode, 'kick_in_r') = 0) then
    result := pm_kick_in_r
  else if (CompareText(cMode, 'corner_kick_l') = 0) then
    result := pm_corner_kick_l
  else if (CompareText(cMode, 'corner_kick_r') = 0) then
    result := pm_corner_kick_r
  else if (CompareText(cMode, 'goal_kick_r') = 0) then
    result := pm_goal_kick_r
  else if (CompareText(cMode, 'goal_kick_l') = 0) then
    result := pm_goal_kick_l
  else if (CompareText(cMode, 'free_kick_l') = 0) then
    result := pm_free_kick_l
  else if (CompareText(cMode, 'free_kick_r') = 0) then
    result := pm_free_kick_r
  else if (CompareText(cMode, 'offside_r') = 0) then
    result := pm_offside_r
  else if (CompareText(cMode, 'offside_l') = 0) then
    result := pm_offside_l
  else if (CompareText(cMode, 'play_on') = 0) then
    result := pm_play_on
  else if (CompareText(cMode, 'half_time') = 0) then
    result := pm_halftime
  else if (CompareText(cMode, 'time_up') = 0) then
    result := pm_time_up
  else if (CompareText(cMode, 'extend') = 0) then
    result := pm_extend
  else
  begin // check for foul...
    result := pm_illegal;
  end;

  // Call the callback function.
end;

function removeAllBrackets(c: string): string;
var
  i: integer;
  n: integer;
begin
  n := length(c);
  i := 1;
  result := '';
  while (i <= n) do
  begin
    if not (c[i] in ['(', ')']) then
      result := result + c[i];
    Inc(i);
  end;
end;

function RemoveSpace(c: string): string;
var
  i: integer;
  n: integer;
begin
  n := length(c);
  i := 1;
  result := '';
  while (i <= n) do
  begin
    if not (c[i] = ' ') then
      result := result + c[i];
    Inc(i);
  end;
end;

function StrToSide(c: string): TSide;
begin
  if c = 'l' then
    result := side_left
  else if c = 'r' then
    result := side_right
  else
    result := side_none;
end;

function StrToPosition(c: string): TPosition;
begin
  if c = 'l' then
    result := poLeft
  else if c = 'c' then
    result := poCenter
  else if c = 'r' then
    result := poRight
  else if c = 't' then
    result := poTop
  else
    result := poBottom;
end;

function StrToKind(c: string): TKind;
begin
  if c = 'goal_own' then
    result := kGoalOwn
  else if c = 'goal_opponent' then
    result := kGoalOpponent
  else // if c = 'player_own' then
    result := kPlayerOwn;
  // etc, etc.
end;

function SideToStr(side: TSide): string;
begin
  case side of
    side_left: result := 'l';
    side_right: result := 'r';
  else
    result := '';
  end;
end;

function PlayModeToStr(pm: TPlayMode): string;
begin
  case pm of
    pm_before_kick_off: result := 'before_kick_off';
    pm_kick_off_l: result := 'kick_off_l';
    pm_kick_off_r: result := 'kick_off_r';
    pm_kick_in_l: result := 'kick_in_l';
    pm_kick_in_r: result := 'kick_in_r';
    pm_corner_kick_l: result := 'corner_kick_l';
    pm_corner_kick_r: result := 'corner_kick_r';
    pm_goal_kick_r: result := 'goal_kick_r';
    pm_goal_kick_l: result := 'goal_kick_l';
    pm_free_kick_l: result := 'free_kick_l';
    pm_free_kick_r: result := 'free_kick_r';
    pm_offside_r: result := 'offside_r';
    pm_offside_l: result := 'offside_l';
    pm_play_on: result := 'play_on';
    pm_halftime: result := 'half_time';
    pm_time_up: result := 'time_up';
    pm_extend: result := 'extend';
  else
    result := '';
  end;
end;

(*
   Absolute angle definition:

                           90
                            |
                            |
                            |
                            |
                            |
                            |
                            |
   180                      |
   -------------------------+------------------------- 0
   -180                     |
                            |
                            |
                            |
                            |
                            |
                            |
                            |
                           -90
*)

(*
  In:
  FaceDir: The direction the player is facing (absolute (-180..180))
  RelAngle: The relative angle (-180..180)
  Out:
  The absolute angle (-180..180)
*)
function RelToAbs(FaceDir, RelAngle: double): double;
begin
  Result := FaceDir - RelAngle;
  if Result > 180 then
    Result := Result - 360;
  if Result < -180 then
    Result := Result + 360;
end;

(*
  In:
  AbsAngle: The absolute angle (-180..180)
  FaceDir: The direction the player is facing (absolute (-180..180))
  Out:
  The relative angle to the facedir (-180..180)
*)
function AbsToRel(AbsAngle, FaceDir: double): double;
begin
  Result := FaceDir - AbsAngle;
  if Result > 180 then
    Result := Result - 360;
  if Result < -180 then
    Result := Result + 360;
end;

function SinAngle(angle: double): double;
begin
  result := sin((angle/180) * Pi);
end;

function CosAngle(angle: double): double;
begin
  result := cos((angle/180) * Pi);
end;

end.


