(*******************************************************************************
*                                                                              *
*                             Delphi BasicConst                                *
*                                                                              *
*                     (C)Copyright 2001, Ferns Paanakker.                      *
*                                                                              *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU General Public License as published by      *
*    the Free Software Foundation; either version 2 of the License, or         *
*    (at your option) any later version.                                       *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU General Public License for more details.                              *
*                                                                              *
*    You should have received a copy of the GNU General Public License         *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************)

unit BasicConst;

interface

uses BasicType;

const
  BPLAYER_DEFAULT_PLAYERNAME = 'Default';
  BPLAYER_DEFAULT_SERVER_HOST = 'localhost';
  BPLAYER_DEFAULT_SERVER_PORT = 6000;
  BPLAYER_DEFAULT_SERVER_VERSION = 4.0;
  BPLAYER_DEFAULT_TEAMNAME = 'Left';
  BPLAYER_DEF_MINIMUM_SEND_INTERVAL = 100;

  DEFAULT_COACHNAME = 'Coach';
  DEFAULT_SERVER_HOST = 'localhost';
  DEFAULT_SERVER_PORT = 6000;
  DEFAULT_COACH_SERVER_PORT = 6001;

  PLAYFIELD_HALF_LENGTH = 52.5;
  PLAYFIELD_HALF_WIDTH = 34.0;
  PLAYFIELD_LENGTH = 105;
  PLAYFIELD_WIDTH = 68;

  PENALTY_AREA_LENGTH = 16.5;
  PENALTY_AREA_HALF_WIDTH = (40.32 / 2);
  GOAL_HALF_WIDTH = (14.02 / 2);
    // AT Humboldt 98 has this one as 7.32/2 (wrong for new sservers)

  DECAY_NORMAL = 0.9;
  DECAY_BALL = 0.8;
  DECAY_FIXED = 0.99;

  (*
    Immovable object Positions.
  *)
  D_IMMOVABLE: array[1..55] of TObjectPosition = (
    (ID: 'lt'; Name: 'UPPER_LEFT_FLAG'; Pos: (X: - PLAYFIELD_HALF_LENGTH; Y:
      PLAYFIELD_HALF_WIDTH)),
    (ID: 'ct'; Name: 'UPPER_MIDDLE_FLAG'; Pos: (X: 0; Y: PLAYFIELD_HALF_WIDTH)),
    (ID: 'rt'; Name: 'UPPER_RIGHT_FLAG'; Pos: (X: PLAYFIELD_HALF_LENGTH; Y:
      PLAYFIELD_HALF_WIDTH)),
    (ID: 'lb'; Name: 'LOWER_LEFT_FLAG'; Pos: (X: - PLAYFIELD_HALF_LENGTH; Y: -
      PLAYFIELD_HALF_WIDTH)),
    (ID: 'cb'; Name: 'LOWER_MIDDLE_FLAG'; Pos: (X: 0; Y: -
      PLAYFIELD_HALF_WIDTH)),
    (ID: 'rb'; Name: 'LOWER_RIGHT_FLAG'; Pos: (X: PLAYFIELD_HALF_LENGTH; Y: -
      PLAYFIELD_HALF_WIDTH)),
    (ID: 'plt'; Name: 'UPPER_LEFT_PENALTY_FLAG'; Pos: (X: - PLAYFIELD_HALF_LENGTH
      + PENALTY_AREA_LENGTH; Y: PENALTY_AREA_HALF_WIDTH)),
    (ID: 'plc'; Name: 'MIDDLE_LEFT_PENALTY_FLAG'; Pos: (X: -
      PLAYFIELD_HALF_LENGTH + PENALTY_AREA_LENGTH; Y: 0)),
    (ID: 'plb'; Name: 'LOWER_LEFT_PENALTY_FLAG'; Pos: (X: - PLAYFIELD_HALF_LENGTH
      + PENALTY_AREA_LENGTH; Y: - PENALTY_AREA_HALF_WIDTH)),
    (ID: 'prt'; Name: 'UPPER_RIGHT_PENALTY_FLAG'; Pos: (X: PLAYFIELD_HALF_LENGTH
      - PENALTY_AREA_LENGTH; Y: PENALTY_AREA_HALF_WIDTH)),
    (ID: 'prc'; Name: 'MIDDLE_RIGHT_PENALTY_FLAG'; Pos: (X: PLAYFIELD_HALF_LENGTH
      - PENALTY_AREA_LENGTH; Y: 0)),
    (ID: 'prb'; Name: 'LOWER_RIGHT_PENALTY_FLAG'; Pos: (X: PLAYFIELD_HALF_LENGTH
      - PENALTY_AREA_LENGTH; Y: - PENALTY_AREA_HALF_WIDTH)),
    (ID: 'l'; Name: 'LEFT_GOAL_CENTER_FLAG'; Pos: (X: - PLAYFIELD_HALF_LENGTH;
      Y: 0)), // goal, not flag
    (ID: 'r'; Name: 'RIGHT_GOAL_CENTER_FLAG'; Pos: (X: PLAYFIELD_HALF_LENGTH; Y:
      0)), // goal, not flag
    (ID: 'c'; Name: 'CENTER_FLAG'; Pos: (X: 0; Y: 0)),
    (ID: 'glt'; Name: 'LEFT_GOAL_TOP_FLAG'; Pos: (X: - PLAYFIELD_HALF_LENGTH; Y:
      GOAL_HALF_WIDTH)),
    (ID: 'glb'; Name: 'LEFT_GOAL_BOTTOM_FLAG'; Pos: (X: - PLAYFIELD_HALF_LENGTH;
      Y: - GOAL_HALF_WIDTH)),
    (ID: 'grt'; Name: 'RIGHT_GOAL_TOP_FLAG'; Pos: (X: PLAYFIELD_HALF_LENGTH; Y:
      GOAL_HALF_WIDTH)),
    (ID: 'grb'; Name: 'RIGHT_GOAL_BOTTOM_FLAG'; Pos: (X: PLAYFIELD_HALF_LENGTH;
      Y: - GOAL_HALF_WIDTH)),
    (ID: 'tl10'; Name: 'OUTSIDE_TOP_LEFT_10_FLAG'; Pos: (X: - 10; Y:
      PLAYFIELD_HALF_WIDTH + 5)),
    (ID: 'tl20'; Name: 'OUTSIDE_TOP_LEFT_20_FLAG'; Pos: (X: - 20; Y:
      PLAYFIELD_HALF_WIDTH + 5)),
    (ID: 'tl30'; Name: 'OUTSIDE_TOP_LEFT_30_FLAG'; Pos: (X: - 30; Y:
      PLAYFIELD_HALF_WIDTH + 5)),
    (ID: 'tl40'; Name: 'OUTSIDE_TOP_LEFT_40_FLAG'; Pos: (X: - 40; Y:
      PLAYFIELD_HALF_WIDTH + 5)),
    (ID: 'tl50'; Name: 'OUTSIDE_TOP_LEFT_50_FLAG'; Pos: (X: - 50; Y:
      PLAYFIELD_HALF_WIDTH + 5)),
    (ID: 'tr10'; Name: 'OUTSIDE_TOP_RIGHT_10_FLAG'; Pos: (X: 10; Y:
      PLAYFIELD_HALF_WIDTH + 5)),
    (ID: 'tr20'; Name: 'OUTSIDE_TOP_RIGHT_20_FLAG'; Pos: (X: 20; Y:
      PLAYFIELD_HALF_WIDTH + 5)),
    (ID: 'tr30'; Name: 'OUTSIDE_TOP_RIGHT_30_FLAG'; Pos: (X: 30; Y:
      PLAYFIELD_HALF_WIDTH + 5)),
    (ID: 'tr40'; Name: 'OUTSIDE_TOP_RIGHT_40_FLAG'; Pos: (X: 40; Y:
      PLAYFIELD_HALF_WIDTH + 5)),
    (ID: 'tr50'; Name: 'OUTSIDE_TOP_RIGHT_50_FLAG'; Pos: (X: 50; Y:
      PLAYFIELD_HALF_WIDTH + 5)),
    (ID: 'bl10'; Name: 'OUTSIDE_BOTTOM_LEFT_10_FLAG'; Pos: (X: - 10; Y: -
      PLAYFIELD_HALF_WIDTH - 5)),
    (ID: 'bl20'; Name: 'OUTSIDE_BOTTOM_LEFT_20_FLAG'; Pos: (X: - 20; Y: -
      PLAYFIELD_HALF_WIDTH - 5)),
    (ID: 'bl30'; Name: 'OUTSIDE_BOTTOM_LEFT_30_FLAG'; Pos: (X: - 30; Y: -
      PLAYFIELD_HALF_WIDTH - 5)),
    (ID: 'bl40'; Name: 'OUTSIDE_BOTTOM_LEFT_40_FLAG'; Pos: (X: - 40; Y: -
      PLAYFIELD_HALF_WIDTH - 5)),
    (ID: 'bl50'; Name: 'OUTSIDE_BOTTOM_LEFT_50_FLAG'; Pos: (X: - 50; Y: -
      PLAYFIELD_HALF_WIDTH - 5)),
    (ID: 'br10'; Name: 'OUTSIDE_BOTTOM_RIGHT_10_FLAG'; Pos: (X: 10; Y: -
      PLAYFIELD_HALF_WIDTH - 5)),
    (ID: 'br20'; Name: 'OUTSIDE_BOTTOM_RIGHT_20_FLAG'; Pos: (X: 20; Y: -
      PLAYFIELD_HALF_WIDTH - 5)),
    (ID: 'br30'; Name: 'OUTSIDE_BOTTOM_RIGHT_30_FLAG'; Pos: (X: 30; Y: -
      PLAYFIELD_HALF_WIDTH - 5)),
    (ID: 'br40'; Name: 'OUTSIDE_BOTTOM_RIGHT_40_FLAG'; Pos: (X: 40; Y: -
      PLAYFIELD_HALF_WIDTH - 5)),
    (ID: 'br50'; Name: 'OUTSIDE_BOTTOM_RIGHT_50_FLAG'; Pos: (X: 50; Y: -
      PLAYFIELD_HALF_WIDTH - 5)),
    (ID: 'lt10'; Name: 'OUTSIDE_LEFT_TOP_10_FLAG'; Pos: (X: -
      PLAYFIELD_HALF_LENGTH - 5; Y: 10)),
    (ID: 'lt20'; Name: 'OUTSIDE_LEFT_TOP_20_FLAG'; Pos: (X: -
      PLAYFIELD_HALF_LENGTH - 5; Y: 20)),
    (ID: 'lt30'; Name: 'OUTSIDE_LEFT_TOP_30_FLAG'; Pos: (X: -
      PLAYFIELD_HALF_LENGTH - 5; Y: 30)),
    (ID: 'lb10'; Name: 'OUTSIDE_LEFT_BOTTOM_10_FLAG'; Pos: (X: -
      PLAYFIELD_HALF_LENGTH - 5; Y: - 10)),
    (ID: 'lb20'; Name: 'OUTSIDE_LEFT_BOTTOM_20_FLAG'; Pos: (X: -
      PLAYFIELD_HALF_LENGTH - 5; Y: - 20)),
    (ID: 'lb30'; Name: 'OUTSIDE_LEFT_BOTTOM_30_FLAG'; Pos: (X: -
      PLAYFIELD_HALF_LENGTH - 5; Y: - 30)),
    (ID: 'rt10'; Name: 'OUTSIDE_RIGHT_TOP_10_FLAG'; Pos: (X:
      PLAYFIELD_HALF_LENGTH + 5; Y: 10)),
    (ID: 'rt20'; Name: 'OUTSIDE_RIGHT_TOP_20_FLAG'; Pos: (X:
      PLAYFIELD_HALF_LENGTH + 5; Y: 20)),
    (ID: 'rt30'; Name: 'OUTSIDE_RIGHT_TOP_30_FLAG'; Pos: (X:
      PLAYFIELD_HALF_LENGTH + 5; Y: 30)),
    (ID: 'rb10'; Name: 'OUTSIDE_RIGHT_BOTTOM_10_FLAG'; Pos: (X:
      PLAYFIELD_HALF_LENGTH + 5; Y: - 10)),
    (ID: 'rb20'; Name: 'OUTSIDE_RIGHT_BOTTOM_20_FLAG'; Pos: (X:
      PLAYFIELD_HALF_LENGTH + 5; Y: - 20)),
    (ID: 'rb30'; Name: 'OUTSIDE_RIGHT_BOTTOM_30_FLAG'; Pos: (X:
      PLAYFIELD_HALF_LENGTH + 5; Y: - 30)),
    (ID: 't0'; Name: 'OUTSIDE_TOP_CENTER_FLAG'; Pos: (X: 0; Y:
      PLAYFIELD_HALF_WIDTH + 5)),
    (ID: 'b0'; Name: 'OUTSIDE_BOTTOM_CENTER_FLAG'; Pos: (X: 0; Y: -
      PLAYFIELD_HALF_WIDTH - 5)),
    (ID: 'l0'; Name: 'OUTSIDE_LEFT_CENTER_FLAG'; Pos: (X: - PLAYFIELD_HALF_LENGTH
      - 5; Y: 0)),
    (ID: 'r0'; Name: 'OUTSIDE_RIGHT_CENTER_FLAG'; Pos: (X: PLAYFIELD_HALF_LENGTH
      + 5; Y: 0))
    );

implementation

end.
