(*******************************************************************************
*                                                                              *
*                             Delphi BasicSettings                             *
*                                                                              *
*                     (C)Copyright 2001, Ferns Paanakker.                      *
*                                                                              *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU General Public License as published by      *
*    the Free Software Foundation; either version 2 of the License, or         *
*    (at your option) any later version.                                       *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU General Public License for more details.                              *
*                                                                              *
*    You should have received a copy of the GNU General Public License         *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************)

unit BasicSettings;

interface

uses classes, sysutils;

type
  TBasicParSettings = class
  private
    { Private declarations }
    FDashIgnoreEffortThreshold: double;
    FPlayerDashPowerMin: double;
    FPlayerTurnMomentMin: double;
    FPlayerKickPowerMin: double;
    FSenseRequestWithActuatorCommands: boolean;
    FAutoAdjustMinimumSendInterval: boolean;
    FAutoPreventExhaustion: boolean;
    FObservationNrForScaling: integer;

    procedure SetDefault;
  public
    { Public declarations }
    property DashIgnoreEffortThreshold: double read FDashIgnoreEffortThreshold;
    property PlayerDashPowerMin: double read FPlayerDashPowerMin;
    property PlayerTurnMomentMin: double read FPlayerTurnMomentMin;
    property PlayerKickPowerMin: double read FPlayerKickPowerMin;
    property SenseRequestWithActuatorCommands: boolean read
      FSenseRequestWithActuatorCommands;
    property AutoAdjustMinimumSendInterval: boolean read
      FAutoAdjustMinimumSendInterval;
    property AutoPreventExhaustion: boolean read FAutoPreventExhaustion;
    property ObservationNrForScaling: integer read FObservationNrForScaling;
    constructor Create;
  end;

  TPlaySettings = class
  private
    { Private declarations }
    FPlayerDecay: double;
    FPlayerPowerRate: double;
    FPlayerSize: double;
    FPlayerRandom: double;
    FPlayerWeight: double;
    FPlayerSpeedMax: double;
    FPlayerMomentInertia: double;
    FPlayerNeckAngleMax: double;
    FStaminaMax: double;
    FStaminaIncMax: double;
    FRecoverDecThreshold: double;
    FEffortDecThreshold: double;
    FEffortIncThreshold: double;
    FBallDecay: double;
    FBallSize: double;
    FBallRandom: double;
    FBallWeight: double;
    FBallPowerRate: double;
    FGoalWidth: double;
    FKickableMargin: double;
    FCatchableAreaLength: double;
    FCatchableAreaWidth: double;
    FSimulatorStep: double;
    FSendStep: double;
    FTouchStep: double;
    FReceiveStep: double;
    FCatchCommandBan: double;
    FHalfTime: integer;
    FUseOffside: boolean;
    FForbidKickoffOffside: boolean;
    FKickoffClearDistance: double;
    FSayMessageSize: integer;
    FMessageSaveInterval: integer;

    procedure SetDefault;
    function GetMaximalKickDest: double;
  public
    { Public declarations }
    property PlayerDecay: double read FPlayerDecay;
    property PlayerPowerRate: double read FPlayerPowerRate;
    property PlayerSize: double read FPlayerSize;
    property PlayerRandom: double read FPlayerRandom;
    property PlayerWeight: double read FPlayerWeight;
    property PlayerSpeedMax: double read FPlayerSpeedMax;
    property PlayerMomentInertia: double read FPlayerMomentInertia;
    property PlayerNeckAngleMax: double read FPlayerNeckAngleMax;
    property StaminaMax: double read FStaminaMax;
    property StaminaIncMax: double read FStaminaIncMax;
    property RecoverDecThreshold: double read FRecoverDecThreshold;
    property EffortDecThreshold: double read FEffortDecThreshold;
    property EffortIncThreshold: double read FEffortIncThreshold;
    property BallDecay: double read FBallDecay;
    property BallSize: double read FBallSize;
    property BallRandom: double read FBallRandom;
    property BallWeight: double read FBallWeight;
    property BallPowerRate: double read FBallPowerRate;
    property GoalWidth: double read FGoalWidth;
    property KickableMargin: double read FKickableMargin;
    property CatchableAreaLength: double read FCatchableAreaLength;
    property CatchableAreaWidth: double read FCatchableAreaWidth;
    property MaximalKickDest: double read GetMaximalKickDest;
    property SimulatorStep: double read FSimulatorStep;
    property SendStep: double read FSendStep;
    property TouchStep: double read FTouchStep;
    property ReceiveStep: double read FReceiveStep;
    property CatchCommandBan: double read FCatchCommandBan;
    property HalfTime: integer read FHalfTime;
    property UseOffside: boolean read FUseOffside;
    property ForbidKickoffOffside: boolean read FForbidKickoffOffside;
    property KickoffClearDistance: double read FKickoffClearDistance;
    property SayMessageSize: integer read FSayMessageSize;
    property MessageSaveInterval: integer read FMessageSaveInterval;

    constructor Create;
    procedure readValues(cFileName: string; cSeparator: char);
  end;

var
  PlaySettings: TPlaySettings;

implementation

{ TPlaySettings }

constructor TPlaySettings.Create;
begin
  inherited;
  SetDefault;
end;

function TPlaySettings.GetMaximalKickDest: double;
begin
  result := 30.0; //?????
end;

procedure TPlaySettings.readValues(cFileName: string; cSeparator: char);
  function StrToBoolean(c: string): boolean;
  begin
    Result := CompareText(c, 'true') = 0;
  end;
var
  sl: TStringList;
  i: integer;
  cIdent, cValue: string;
begin
  setDefault;
  sl := TStringList.Create;
  try
    sl.LoadFromFile(cFileName);
    for i := 0 to sl.count - 1 do
    begin
      if (Pos(cSeparator, sl[i]) > 0) then
      begin
        cIdent := trim(Copy(sl[i], 1, Pos(cSeparator, sl[i]) - 1));
        cValue := trim(Copy(sl[i], Pos(cSeparator, sl[i]) + 1, length(sl[i])));

        if CompareText('player_decay', cIdent) = 0 then
          FPlayerDecay := StrToFloat(cValue)
        else if CompareText('dash_power_rate', cIdent) = 0 then
          FPlayerPowerRate := StrToFloat(cValue)
        else if CompareText('player_size', cIdent) = 0 then
          FPlayerSize := StrToFloat(cValue)
        else if CompareText('player_rand', cIdent) = 0 then
          FPlayerRandom := StrToFloat(cValue)
        else if CompareText('player_weight', cIdent) = 0 then
          FPlayerWeight := StrToFloat(cValue)
        else if CompareText('player_speed_max', cIdent) = 0 then
          FPlayerSpeedMax := StrToFloat(cValue)
        else if CompareText('inertia_moment', cIdent) = 0 then
          FPlayerMomentInertia := StrToFloat(cValue)
        else if CompareText('player_neck_angle_max', cIdent) = 0 then
          FPlayerNeckAngleMax := StrToFloat(cValue)
        else if CompareText('stamina_max', cIdent) = 0 then
          FStaminaMax := StrToFloat(cValue)
        else if CompareText('stamina_inc_max', cIdent) = 0 then
          FStaminaIncMax := StrToFloat(cValue)
        else if CompareText('recover_dec_thr', cIdent) = 0 then
          FRecoverDecThreshold := StrToFloat(cValue)
        else if CompareText('effort_dec_thr', cIdent) = 0 then
          FEffortDecThreshold := StrToFloat(cValue)
        else if CompareText('effort_inc_thr', cIdent) = 0 then
          FEffortIncThreshold := StrToFloat(cValue)
        else if CompareText('ball_decay', cIdent) = 0 then
          FBallDecay := StrToFloat(cValue)
        else if CompareText('ball_size', cIdent) = 0 then
          FBallSize := StrToFloat(cValue)
        else if CompareText('ball_rand', cIdent) = 0 then
          FBallRandom := StrToFloat(cValue)
        else if CompareText('ball_weight', cIdent) = 0 then
          FBallWeight := StrToFloat(cValue)
        else if CompareText('kick_power_rate', cIdent) = 0 then
          FBallPowerRate := StrToFloat(cValue)
        else if CompareText('goal_width', cIdent) = 0 then
          FGoalWidth := StrToFloat(cValue)
        else if CompareText('kickable_margin', cIdent) = 0 then
          FKickableMargin := StrToFloat(cValue)
        else if CompareText('catchable_area_l', cIdent) = 0 then
          FCatchableAreaLength := StrToFloat(cValue)
        else if CompareText('catchable_area_w', cIdent) = 0 then
          FCatchableAreaWidth := StrToFloat(cValue)
        else if CompareText('simulator_step', cIdent) = 0 then
          FSimulatorStep := StrToFloat(cValue)
        else if CompareText('send_step', cIdent) = 0 then
          FSendStep := StrToFloat(cValue)
        else if CompareText('touch_step', cIdent) = 0 then
          FTouchStep := StrToFloat(cValue)
        else if CompareText('recv_step', cIdent) = 0 then
          FReceiveStep := StrToFloat(cValue)
        else if CompareText('catch_ban_cycle', cIdent) = 0 then
          FCatchCommandBan := StrToFloat(cValue)
        else if CompareText('half_time', cIdent) = 0 then
          FHalfTime := StrToInt(cValue)
        else if CompareText('use_offside', cIdent) = 0 then
          FUseOffside := StrToBoolean(cValue)
        else if CompareText('forbid_kick_off_offside', cIdent) = 0 then
          FForbidKickoffOffside := StrToBoolean(cValue)
        else if CompareText('kick_off_clear_distance', cIdent) = 0 then
          FKickoffClearDistance := StrToFloat(cValue)
        else if CompareText('say_msg_size', cIdent) = 0 then
          FSayMessageSize := StrToInt(cValue)
        else if CompareText('message_save_interval', cIdent) = 0 then
          FMessageSaveInterval := StrToInt(cValue);
      end;
    end;
  finally
    sl.Free;
  end;
end;

procedure TPlaySettings.SetDefault;
begin
  FPlayerDecay := 0.4;
  FPlayerPowerRate := 0.01;
  FPlayerSize := 0.8;
  FPlayerRandom := 0.1;
  FPlayerWeight := 60.0;
  FPlayerSpeedMax := 1.0;
  FPlayerMomentInertia := 5.0;
  FPlayerNeckAngleMax := 90.0;
  FStaminaMax := 2000.0;
  FStaminaIncMax := 20.0;
  FRecoverDecThreshold := 0.3;
  FEffortDecThreshold := 0.3;
  FEffortIncThreshold := 0.6;
  FBallDecay := 0.94;
  FBallSize := 0.085;
  FBallRandom := 0.05;
  FBallWeight := 0.2;
  FBallPowerRate := 0.016;
  FGoalWidth := 14.02;
  FKickableMargin := 1.0;
  FCatchableAreaLength := 2.0;
  FCatchableAreaWidth := 1.0;
  FSimulatorStep := 100.0;
  FSendStep := 150.0;
  FTouchStep := 500.0;
  FReceiveStep := 10.0;
  FCatchCommandBan := 5.0;
  FHalfTime := 3000;
  FUseOffside := true;
  FForbidKickoffOffside := true;
  FKickoffClearDistance := 9.15;
  FSayMessageSize := 512;
  FMessageSaveInterval := 0;
end;

{ TBasicParSettings }

constructor TBasicParSettings.Create;
begin
  inherited;
  SetDefault;
end;

procedure TBasicParSettings.SetDefault;
begin
  FDashIgnoreEffortThreshold := 0.5;
  FPlayerDashPowerMin := 0.01;
  FPlayerTurnMomentMin := 0.01;
  FPlayerKickPowerMin := 0.01;
  FSenseRequestWithActuatorCommands := true;
  FAutoAdjustMinimumSendInterval := true;
  FAutoPreventExhaustion := true;
  FObservationNrForScaling := 10;
end;

end.
