(*******************************************************************************
*                                                                              *
*                                Delphi Main                                   *
*                                                                              *
*                     (C)Copyright 2001, Ferns Paanakker.                      *
*                                                                              *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU General Public License as published by      *
*    the Free Software Foundation; either version 2 of the License, or         *
*    (at your option) any later version.                                       *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU General Public License for more details.                              *
*                                                                              *
*    You should have received a copy of the GNU General Public License         *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************)

unit main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, IdBaseComponent, IdComponent, IdUDPBase, IdUDPClient, ExtCtrls,
  math,
  BasicConst, BasicSettings, BasicPlayer, BasicType, BasicAssist, BasicObjects;

type

  TFrmBasicPlayer = class(TForm)
    Panel1: TPanel;
    Button1: TButton;
    Button2: TButton;
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  private
    { Private declarations }
    player: TBasicPlayer;
    voList: TVOList;
    isFirst: boolean;
    procedure Progress(Sender: TObject);
  public
    { Public declarations }
  end;

var
  FrmBasicPlayer: TFrmBasicPlayer;

implementation

{$R *.DFM}

procedure TFrmBasicPlayer.Button1Click(Sender: TObject);
begin
  Button1.Enabled := False;
  Button2.Enabled := True;

  isFirst := true;
  PlaySettings := TPlaySettings.Create;
  if ParamCount = 0 then
    player := TBasicPlayer.Create('myTeam')
  else
    player := TBasicPlayer.Create(ParamStr(1));
  player.OnProgress := Progress;
  player.Log := nil;//Memo1.Lines;
  player.joinMatch;
  player.mainLoop; // start playing
end;

procedure TFrmBasicPlayer.Progress(Sender: TObject);
var
  bo: TBallObject;
  go: TGoalObject;
begin
  if player.CurTime mod 20 = 7 then
    player.requestSenseInfo;

  (*
     Use this time to perform some actions...
  *)
  if ((isFirst) and (player.PlayMode = pm_before_kick_off)) then
  begin
    if isFirst then
    begin
      if player.Side = side_left then
        player.move(-15, 0)
      else
        player.move(15, 0);

      isFirst := false;
    end;
  end;

  if not (player.PlayMode in [pm_illegal, pm_before_kick_off]) then
  begin
    // only do something if we have new visual information...
    if player.gotNewVisualInformation then
    begin
      // Get all object with a confidence level of 0.6 that they are at the
      // last known location: so 60% confidence that the information is correct
      voList := player.GetVOList([kGoalOpponent, kBall],0.6);
      go := TGoalObject(voList.getObject(kGoalOpponent));
      bo := TBallObject(voList.getObject(kBall));
      if Assigned(bo) then
      begin
        if bo.isKickable then
        begin
          if Assigned(go) then
            player.kick(40, go.Direction)
          else // we haven't even seen the goal yet, so search for it
            player.turn(player.halfViewAngle * 1.9);
        end
        else
        begin
          if (abs(bo.Direction) < 10) then
            player.dash(min(35, player.Distance2DashPower(bo.Distance)))
          else
            player.turn(bo.Direction);
        end;
      end
      else // we haven't even seen the ball yet, so search for it
        player.turn(player.halfViewAngle * 1.9);
      voList.Free;
    end;
  end;
  Application.ProcessMessages;
end;

procedure TFrmBasicPlayer.Button2Click(Sender: TObject);
begin
  Button2.Enabled := False;
  Button1.Enabled := True;
  player.leavematch;
end;

procedure TFrmBasicPlayer.FormDestroy(Sender: TObject);
begin
  if assigned(player) then
    Player.Free;
  if Assigned(PlaySettings) then
    PlaySettings.Free;
end;

end.
